<?php
namespace OCA\Dematpayslip\Db;

use OCP\IDbConnection;
use OCP\AppFramework\Db\QBMapper;

class DematpayslipArchiveMapper extends QBMapper {

    public function __construct(IDbConnection $db) {
        parent::__construct($db, 'dematpayslip_archive', DematpayslipArchive::class);
    }

    public function find(int $id) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('id', $qb->createNamedParameter($id))
            );

        return $this->findEntity($qb);
    }

    public function findAllByIdFile(int $idFile) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('id_file', $qb->createNamedParameter($idFile))
            );

        return $this->findEntities($qb);
    }

    public function findAllByFilePath(string $filePath) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('file_path', $qb->createNamedParameter($filePath))
            );

        return $this->findEntities($qb);
    }

    public function findAllArchived(int $archived) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*');
        $qb->from($this->getTableName());
        $qb->where(
            $qb->expr()->eq('disabled', $qb->createNamedParameter(0))
        );

        if ($archived == 1) {
            $qb->where(
                $qb->expr()->isNotNull('pastell_id_document')
            );
        } elseif ($archived == 0) {
            $qb->where(
                $qb->expr()->isNull('pastell_id_document')
            );
        }

        return $this->findEntities($qb);
    }

    public function findAll() {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName());

        return $this->findEntities($qb);
    }
}
